package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.WINFOArtifact;

import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.ReportFacet;
import de.intevation.flys.artifacts.model.WaterlevelFacet;
import de.intevation.flys.artifacts.model.WQKms;
import de.intevation.flys.artifacts.model.WQCKms;
import de.intevation.flys.artifacts.model.CalculationResult;

import de.intevation.flys.artifacts.model.DataFacet;

public class DischargeLongitudinalSection
extends      DefaultState
implements   FacetTypes
{
    private static Logger logger =
        Logger.getLogger(DischargeLongitudinalSection.class);


    @Override
    public Object computeAdvance(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets, 
        Object       old
    ) {
        WINFOArtifact winfo = (WINFOArtifact)artifact;

        CalculationResult res = old instanceof CalculationResult
            ? (CalculationResult)old
            : winfo.getDischargeLongitudinalSectionData();

        if (facets == null) {
            return res;
        }

        WQKms [] wqkms = (WQKms [])res.getData();

        for (int i = 0; i < wqkms.length; i++) {
            String nameW = null;
            String nameQ = null;

            if (winfo.isQ()) {
                nameQ = wqkms[i].getName();
                nameW = "W(" + nameQ + ")";
            }
            else {
                nameW = wqkms[i].getName();
                nameQ = "Q(" + nameQ + ")";
            }

            Facet w = new WaterlevelFacet(
                i, DISCHARGE_LONGITUDINAL_W, nameW);

            Facet q = new WaterlevelFacet(
                i, DISCHARGE_LONGITUDINAL_Q, nameQ);

            facets.add(w);
            facets.add(q);

            if (wqkms[i] instanceof WQCKms) {
                // TODO DO i18n

                String nameC = nameW.replace(
                    "Benutzerdefiniert",
                    "Benutzerdefiniert [korrigiert]");

                Facet c = new WaterlevelFacet(
                    i, DISCHARGE_LONGITUDINAL_C, nameC);

                facets.add(c);
            }
        }

        if (wqkms.length > 0) {
            facets.add(new DataFacet(CSV, "CSV data"));
            facets.add(new DataFacet(WST, "WST data"));
        }

        if (res.getReport().hasProblems()) {
            facets.add(new ReportFacet());
        }

        return res;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
